summaryrefslogtreecommitdiff
path: root/src/vm/stackwalk.cpp
diff options
context:
space:
mode:
authorJan Kotas <jkotas@microsoft.com>2016-01-28 14:51:35 -0800
committerJan Kotas <jkotas@microsoft.com>2016-01-28 14:51:35 -0800
commit02d8c0f28c8008aef40775ed55e123e8280094ef (patch)
treef46aac1472016b4a4e7a7f2d2c0ea3a8a6b1e771 /src/vm/stackwalk.cpp
parent813faa439d8d99c248652eaa1e3a57a28a422d91 (diff)
parente782a1421a11862251470ad5e497d709fd4eebe0 (diff)
downloadcoreclr-02d8c0f28c8008aef40775ed55e123e8280094ef.tar.gz
coreclr-02d8c0f28c8008aef40775ed55e123e8280094ef.tar.bz2
coreclr-02d8c0f28c8008aef40775ed55e123e8280094ef.zip
Merge pull request #2893 from swaroop-sridhar/redirect
Fix an assert failure in GCStress testing
Diffstat (limited to 'src/vm/stackwalk.cpp')
-rw-r--r--src/vm/stackwalk.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/vm/stackwalk.cpp b/src/vm/stackwalk.cpp
index f61d74a7dc..ef909c9d9d 100644
--- a/src/vm/stackwalk.cpp
+++ b/src/vm/stackwalk.cpp
@@ -1563,8 +1563,8 @@ BOOL StackFrameIterator::IsValid(void)
// we started?
//DevDiv 168789: In GCStress >= 4 two threads could race on triggering GC;
// if the one that just made p/invoke call is second and hits the trap instruction
// before call to syncronize with GC, it will push RedirectedThreadFrame concurrently
// with GC stackwalking.
// In normal case (no GCStress), after p/invoke, IL_STUB will check if GC is in progress and syncronize.
BOOL bRedirectedPinvoke = FALSE;
@@ -1575,7 +1575,8 @@ BOOL StackFrameIterator::IsValid(void)
(m_pRealStartFrame->GetVTablePtr() == InlinedCallFrame::GetMethodFrameVPtr()) &&
(m_pThread->GetFrame() != NULL) &&
(m_pThread->GetFrame() != FRAME_TOP) &&
- (m_pThread->GetFrame()->GetVTablePtr() == RedirectedThreadFrame::GetMethodFrameVPtr()));
+ ((m_pThread->GetFrame()->GetVTablePtr() == ResumableFrame::GetMethodFrameVPtr()) ||
+ (m_pThread->GetFrame()->GetVTablePtr() == RedirectedThreadFrame::GetMethodFrameVPtr())));
#endif // FEATURE_HIJACK
_ASSERTE( (m_pStartFrame != NULL) ||
@@ -1563,8 +1563,8 @@ BOOL StackFrameIterator::IsValid(void)
//DevDiv 168789: In GCStress >= 4 two threads could race on triggering GC;
// if the one that just made p/invoke call is second and hits the trap instruction
- // before call to syncronize with GC, it will push RedirectedThreadFrame concurrently
- // with GC stackwalking.
+ // before call to syncronize with GC, it will push a frame [ResumableFrame on Unix
+ // and RedirectedThreadFrame on Windows] concurrently with GC stackwalking.
// In normal case (no GCStress), after p/invoke, IL_STUB will check if GC is in progress and syncronize.
BOOL bRedirectedPinvoke = FALSE;